@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 
 from urllib import urlencode
+from urlparse import unquote
 from lxml import html
 from searx.engines.xpath import extract_text, extract_url
 
@@ -15,6 +16,19 @@ suggestion_xpath = '//div[@id="satat"]//a'
 paging = True
 
 
+def parse_url(url_string):
+    endings = ['/RS', '/RK']
+    endpositions = []
+    start = url_string.find('http', url_string.find('/RU=')+1)
+    for ending in endings:
+        endpos = url_string.rfind(ending)
+        if endpos > -1:
+            endpositions.append(endpos)
+
+    end = min(endpositions)
+    return unquote(url_string[start:end])
+
+
 def request(query, params):
     offset = (params['pageno'] - 1) * 10 + 1
     if params['language'] == 'all':
@@ -33,8 +47,11 @@ def response(resp):
     dom = html.fromstring(resp.text)
 
     for result in dom.xpath(results_xpath):
-        url = extract_url(result.xpath(url_xpath), search_url)
-        title = extract_text(result.xpath(title_xpath)[0])
+        try:
+            url = parse_url(extract_url(result.xpath(url_xpath), search_url))
+            title = extract_text(result.xpath(title_xpath)[0])
+        except:
+            continue
         content = extract_text(result.xpath(content_xpath)[0])
         results.append({'url': url, 'title': title, 'content': content})
 
