@@ -1,13 +1,17 @@
-from HTMLParser import HTMLParser
 #import htmlentitydefs
-import csv
 from codecs import getincrementalencoder
-import cStringIO
-import re
+from HTMLParser import HTMLParser
 from random import choice
 
+import cStringIO
+import csv
+import os
+import re
+
 ua_versions = ('26.0', '27.0', '28.0')
-ua_os = ('Windows NT 6.3; WOW64', 'X11; Linux x86_64; rv:26.0')
+ua_os = ('Windows NT 6.3; WOW64',
+         'X11; Linux x86_64',
+         'X11; Linux x86')
 ua = "Mozilla/5.0 ({os}) Gecko/20100101 Firefox/{version}"
 
 
@@ -28,7 +32,8 @@ def highlight_content(content, query):
     query = query.decode('utf-8')
     if content.lower().find(query.lower()) > -1:
         query_regex = u'({0})'.format(re.escape(query))
-        content = re.sub(query_regex, '<b>\\1</b>', content, flags=re.I | re.U)
+        content = re.sub(query_regex, '<span class="highlight">\\1</span>',
+                         content, flags=re.I | re.U)
     else:
         regex_parts = []
         for chunk in query.split():
@@ -37,7 +42,8 @@ def highlight_content(content, query):
             else:
                 regex_parts.append(u'{0}'.format(re.escape(chunk)))
         query_regex = u'({0})'.format('|'.join(regex_parts))
-        content = re.sub(query_regex, '<b>\\1</b>', content, flags=re.I | re.U)
+        content = re.sub(query_regex, '<span class="highlight">\\1</span>',
+                         content, flags=re.I | re.U)
 
     return content
 
@@ -106,3 +112,17 @@ class UnicodeWriter:
     def writerows(self, rows):
         for row in rows:
             self.writerow(row)
+
+
+def get_themes(root):
+    """Returns available themes list."""
+
+    static_path = os.path.join(root, 'static')
+    static_names = set(os.listdir(static_path))
+    templates_path = os.path.join(root, 'templates')
+    templates_names = set(os.listdir(templates_path))
+
+    themes = []
+    for name in static_names.intersection(templates_names):
+        themes += [name]
+    return static_path, templates_path, themes
